==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Información de imágen</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Añadir a álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuevo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas las imágenes</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Quitar del álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritos</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No tiene permisos para ver esta imagen</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Fecha de modificación</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño de archivo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fecha de la captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Longitud focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espacio de color</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamaño 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar a la ventana</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Salir de pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar ventana de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar ventana de navegación</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información de imágen</translation>
    </message>
    <message>
        <source>day</source>
        <translation>día</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Ingrese un nuevo nombre</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No se econtraron archivos de imágen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No se encontró el archivo de imagen</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>No tiene permiso para ver el archivo</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.21.orig.tar.xz: image-editor-1.0.21/libimageviewer/translations/libimageviewer_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Información de imágen</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Añadir a álbum</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuevo álbum</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Todas las imágenes</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Quitar del álbum</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Añadir a favoritos</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No tiene permisos para ver esta imagen</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Fecha de modificación</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño de archivo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fecha de la captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Longitud focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flash</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espacio de color</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamaño 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar a la ventana</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar hacia la izquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar hacia la derecha</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Salir de pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar ventana de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar ventana de navegación</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información de imágen</translation>
    </message>
    <message>
        <source>day</source>
        <translation>día</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Ingrese un nuevo nombre</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No se econtraron archivos de imágen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No se encontró el archivo de imagen</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>No tiene permiso para ver el archivo</translation>
    </message>
</context>
</TS>
